@@ -68,7 +68,7 @@ struct sx_radix_node *sx_radix_tree_lookup_exact(struct sx_radix_tree *tree,
 	struct sx_prefix *prefix);
 
 struct sx_prefix *sx_prefix_alloc(struct sx_prefix *p);
-void sx_prefix_destroy(struct sx_prefix *p);
+void sx_prefix_free(struct sx_prefix *p);
 void sx_radix_node_destroy(struct sx_radix_node *p);
 void sx_prefix_adjust_masklen(struct sx_prefix *p);
 struct sx_prefix *sx_prefix_new(int af, char *text);
